==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/el.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Συλλογή",
    "There was a problem reading files from this album" : "Πρόβλημα ανάγνωσης αρχείων από αυτό το άλμπουμ",
    "Aborting preview. Could not find the file" : "Ακύρωση προεπισκόπησης. Αδυναμία εύρεσης αρχείου",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "Invalid server url" : "Μη έγκυρη url δικομιστή",
    "Gallery view" : "Προβολή Συλλογής",
    "Could not load the description" : "Αδυναμία φόρτωσης περιγραφής",
    "Could not load the description: " : "Αδυναμία φόρτωσης της περιγραφής:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Αδυναμία φόρτωσης σημείωσης πνευματικών δικαιωμάτων:",
    "Copyright notice" : "Σημείωση Πνευμ. Δικαιωμάτων",
    "Link to copyright document" : "Σύνδεσμος για έγγραφο πνευματικών δικαιωμάτων",
    "This application may not work properly on your browser." : "Αυτή η εφαρμογή ενδέχεται να μη δουλεύει σωστά στον περιηγητή σας.",
    "For an improved experience, please install one of the following alternatives" : "Για βελτιωμένη εμπειρία, παρακαλώ εγκαταστήστε μία από τις ακόλουθες εναλλακτικές",
    "Your browser is not supported!" : "Ο περιηγητής σας δεν υποστηρίζεται!",
    "please install one of the following alternatives" : "παρακαλώ εγκαταστήστε μία από τις ακόλουθες εναλλακτικές",
    "Album cannot be shown" : "Το άλμπουμ δεν μπορεί να προβληθεί",
    "No media files found" : "Δεν βρέθηκαν πολυμέσα",
    "Upload pictures in the files app to display them here" : "Mεταφορτώστε εικόνες στην εφαρμογή \"Αρχεία\" για να εμφανιστούν εδώ.",
    "Configuration error" : "Σφάλμα ρυθμίσεων",
    "New" : "Νέο",
    "Hide Album" : "Απόκρυψη άλμπουμ",
    "Could not hide album" : "Αδυναμία απόκρυψης άλμπουμ",
    "Error loading slideshow template" : "Σφάλμα φόρτωσης προτύπου προβολής διαφανειών",
    "Next" : "Επόμενο",
    "Play" : "Αναπαραγωγή",
    "Pause" : "Παύση",
    "Previous" : "Προηγούμενο",
    "Close" : "Κλείσιμο",
    "Download" : "Λήψη",
    "Toggle background" : "Αλλαγή φόντου",
    "Delete" : "Διαγραφή",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του \"{file}\"",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "Upload" : "Μεταφόρτωση",
    "Error" : "Σφάλμα",
    "Error while sharing" : "Σφάλμα κατά τον διαμοιρασμό",
    "Error while unsharing" : "Σφάλμα κατά το σταμάτημα του διαμοιρασμού",
    "Error while changing permissions" : "Σφάλμα κατά την αλλαγή των δικαιωμάτων",
    "Shared with you and the group {group} by {owner}" : "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
    "Shared with you by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Share with users or groups …" : "Διαμοιρασμός με χρήστες ή ομάδες ...",
    "Share with users, groups or remote users …" : "Διαμοιρασμός με χρήστες, ομάδες ή απομακρυσμένους χρήστες ...",
    "Share" : "Διαμοιρασμός",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "The public link will expire no later than {days} days after it is created" : "Ο δημόσιος σύνδεσμος θα απενεργοποιηθεί το πολύ {days} ημέρες μετά την δημιουργία του",
    "Link" : "Σύνδεσμος",
    "Password protect" : "Προστασία συνθηματικού",
    "Password" : "Κωδικός πρόσβασης",
    "Choose a password for the public link" : "Επιλέξτε κωδικό για τον δημόσιο σύνδεσμο",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Email link to person" : "Αποστολή συνδέσμου με email ",
    "Send" : "Αποστολή",
    "Set expiration date" : "Ορισμός ημ. λήξης",
    "Expiration" : "Λήξη",
    "Expiration date" : "Ημερομηνία λήξης",
    "An error occured. Please try again" : "Ένα σφάλμα προέκυψε. Παρακαλώ προσπαθήστε ξανά",
    "Adding user..." : "Προσθήκη χρήστη ...",
    "group" : "ομάδα",
    "remote" : "απομακρυσμένα",
    "Resharing is not allowed" : "Ξαναμοιρασμός δεν επιτρέπεται",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "notify by email" : "ειδοποίηση με email",
    "can share" : "δυνατότητα διαμοιρασμού",
    "can edit" : "δυνατότητα επεξεργασίας",
    "access control" : "έλεγχος πρόσβασης",
    "create" : "δημιουργία",
    "change" : "αλλαγή",
    "delete" : "διαγραφή",
    "Password protected" : "Προστασία με συνθηματικό",
    "Error unsetting expiration date" : "Σφάλμα κατά την διαγραφή της ημ. λήξης",
    "Error setting expiration date" : "Σφάλμα κατά τον ορισμό ημ. λήξης",
    "Sending ..." : "Αποστολή...",
    "Email sent" : "Το Email απεστάλη ",
    "Warning" : "Προειδοποίηση",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Sort by date" : "Ταξινόμηση κατά ημερομηνία",
    "Sort by name" : "Ταξινόμηση κατά όνομα",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "Album information" : "Πληροφορίες λευκώματος",
    "File list" : "Λίστα αρχείων",
    "Sorry, this file could not be found." : "Συγγνώμη, αυτό το αρχείο δεν βρέθηκε.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the wrong file ID was provided" : "δόθηκε λάθος ID αρχείου",
    "the file was removed" : "το αρχείο αφαιρέθηκε",
    "the file is corrupt" : "το αρχείο είναι κατεστραμμένο",
    "the encryption key is missing" : "λείπει το κλειδί κρυπτογράφησης",
    "Here is the error message returned by the server: " : "Εδώ είναι το μήνυμα σφάλματος που επέστρεψε ο διακομιστής:",
    "Sorry, but the server could not fulfill your request." : "Συγγνώμη αλλά ο διακομιστής δεν μπόρεσε να εκπληρώσει το αίτημά σας.",
    "Possible reasons for the problem:" : "Πιθανές αιτίες του πορβλήματος:",
    "a conflicting app was installed" : "εγκαταστάθηκε μια ασύμβατη εφαρμογή",
    "a required component is missing or was disconnected" : "λείπει ή δεν είναι συνδεδεμένο ένα απαιτούμενο στοιχείο",
    "the filesystem is not readable" : "το σύστημα αρχείων δεν είναι αναγνώσιμο",
    "For more information, please contact your friendly ownCloud administrator." : "Για περισσότερες πληροφορίες παρακαλούμε, επικοινωνήστε με το φιλικό διαχειριστή του συστήματός σας.",
    "Sorry, this link doesn't seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος φαίνεται ότι δεν ισχύει πια.",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link has expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more information, please ask the person who has sent you this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud",
    "Picture view" : "Προβολή εικονιδίων"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/el.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Συλλογή",
    "There was a problem reading files from this album" : "Πρόβλημα ανάγνωσης αρχείων από αυτό το άλμπουμ",
    "Aborting preview. Could not find the file" : "Ακύρωση προεπισκόπησης. Αδυναμία εύρεσης αρχείου",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "No compatible server found at {remote}" : "Δεν βρέθηκε συμβατός διακομιστής σε {remote}",
    "Invalid server url" : "Μη έγκυρη url δικομιστή",
    "Gallery view" : "Προβολή Συλλογής",
    "Could not load the description" : "Αδυναμία φόρτωσης περιγραφής",
    "Could not load the description: " : "Αδυναμία φόρτωσης της περιγραφής:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Αδυναμία φόρτωσης σημείωσης πνευματικών δικαιωμάτων:",
    "Copyright notice" : "Σημείωση Πνευμ. Δικαιωμάτων",
    "Link to copyright document" : "Σύνδεσμος για έγγραφο πνευματικών δικαιωμάτων",
    "This application may not work properly on your browser." : "Αυτή η εφαρμογή ενδέχεται να μη δουλεύει σωστά στον περιηγητή σας.",
    "For an improved experience, please install one of the following alternatives" : "Για βελτιωμένη εμπειρία, παρακαλώ εγκαταστήστε μία από τις ακόλουθες εναλλακτικές",
    "Your browser is not supported!" : "Ο περιηγητής σας δεν υποστηρίζεται!",
    "please install one of the following alternatives" : "παρακαλώ εγκαταστήστε μία από τις ακόλουθες εναλλακτικές",
    "Album cannot be shown" : "Το άλμπουμ δεν μπορεί να προβληθεί",
    "No media files found" : "Δεν βρέθηκαν πολυμέσα",
    "Upload pictures in the files app to display them here" : "Mεταφορτώστε εικόνες στην εφαρμογή \"Αρχεία\" για να εμφανιστούν εδώ.",
    "Configuration error" : "Σφάλμα ρυθμίσεων",
    "New" : "Νέο",
    "Hide Album" : "Απόκρυψη άλμπουμ",
    "Could not hide album" : "Αδυναμία απόκρυψης άλμπουμ",
    "Error loading slideshow template" : "Σφάλμα φόρτωσης προτύπου προβολής διαφανειών",
    "Next" : "Επόμενο",
    "Play" : "Αναπαραγωγή",
    "Pause" : "Παύση",
    "Previous" : "Προηγούμενο",
    "Close" : "Κλείσιμο",
    "Download" : "Λήψη",
    "Toggle background" : "Αλλαγή φόντου",
    "Delete" : "Διαγραφή",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του \"{file}\"",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "Upload" : "Μεταφόρτωση",
    "Error" : "Σφάλμα",
    "Error while sharing" : "Σφάλμα κατά τον διαμοιρασμό",
    "Error while unsharing" : "Σφάλμα κατά το σταμάτημα του διαμοιρασμού",
    "Error while changing permissions" : "Σφάλμα κατά την αλλαγή των δικαιωμάτων",
    "Shared with you and the group {group} by {owner}" : "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
    "Shared with you by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "Share with users or groups …" : "Διαμοιρασμός με χρήστες ή ομάδες ...",
    "Share with users, groups or remote users …" : "Διαμοιρασμός με χρήστες, ομάδες ή απομακρυσμένους χρήστες ...",
    "Share" : "Διαμοιρασμός",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "The public link will expire no later than {days} days after it is created" : "Ο δημόσιος σύνδεσμος θα απενεργοποιηθεί το πολύ {days} ημέρες μετά την δημιουργία του",
    "Link" : "Σύνδεσμος",
    "Password protect" : "Προστασία συνθηματικού",
    "Password" : "Κωδικός πρόσβασης",
    "Choose a password for the public link" : "Επιλέξτε κωδικό για τον δημόσιο σύνδεσμο",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Email link to person" : "Αποστολή συνδέσμου με email ",
    "Send" : "Αποστολή",
    "Set expiration date" : "Ορισμός ημ. λήξης",
    "Expiration" : "Λήξη",
    "Expiration date" : "Ημερομηνία λήξης",
    "No users or groups found for {search}" : "Δεν βρέθηκαν χρήστες ή ομάδες για {search}",
    "No users found for {search}" : "Δεν βρέθηκαν χρήστες για {search}",
    "An error occured. Please try again" : "Ένα σφάλμα προέκυψε. Παρακαλώ προσπαθήστε ξανά",
    "Adding user..." : "Προσθήκη χρήστη ...",
    "group" : "ομάδα",
    "remote" : "απομακρυσμένα",
    "Resharing is not allowed" : "Ξαναμοιρασμός δεν επιτρέπεται",
    "Error while retrieving shares" : "Σφάλμα κατά την λήψη κοινόχρηστων",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "notify by email" : "ειδοποίηση με email",
    "can share" : "δυνατότητα διαμοιρασμού",
    "can edit" : "δυνατότητα επεξεργασίας",
    "access control" : "έλεγχος πρόσβασης",
    "create" : "δημιουργία",
    "change" : "αλλαγή",
    "delete" : "διαγραφή",
    "Password protected" : "Προστασία με συνθηματικό",
    "Error unsetting expiration date" : "Σφάλμα κατά την διαγραφή της ημ. λήξης",
    "Error setting expiration date" : "Σφάλμα κατά τον ορισμό ημ. λήξης",
    "Sending ..." : "Αποστολή...",
    "Email sent" : "Το Email απεστάλη ",
    "Warning" : "Προειδοποίηση",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Sort by date" : "Ταξινόμηση κατά ημερομηνία",
    "Sort by name" : "Ταξινόμηση κατά όνομα",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "Album information" : "Πληροφορίες λευκώματος",
    "File list" : "Λίστα αρχείων",
    "Sorry, this file could not be found." : "Συγγνώμη, αυτό το αρχείο δεν βρέθηκε.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the wrong file ID was provided" : "δόθηκε λάθος ID αρχείου",
    "the file was removed" : "το αρχείο αφαιρέθηκε",
    "the file is corrupt" : "το αρχείο είναι κατεστραμμένο",
    "the encryption key is missing" : "λείπει το κλειδί κρυπτογράφησης",
    "Here is the error message returned by the server: " : "Εδώ είναι το μήνυμα σφάλματος που επέστρεψε ο διακομιστής:",
    "For more information, please contact your friendly Nextcloud administrator." : "Για περισσότερες πληροφορίες, επικοινωνήστε με τον υπεύθυνο διαχειριστή του Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Συγγνώμη αλλά ο διακομιστής δεν μπόρεσε να εκπληρώσει το αίτημά σας.",
    "Possible reasons for the problem:" : "Πιθανές αιτίες του πορβλήματος:",
    "a conflicting app was installed" : "εγκαταστάθηκε μια ασύμβατη εφαρμογή",
    "a required component is missing or was disconnected" : "λείπει ή δεν είναι συνδεδεμένο ένα απαιτούμενο στοιχείο",
    "the filesystem is not readable" : "το σύστημα αρχείων δεν είναι αναγνώσιμο",
    "For more information, please contact your friendly ownCloud administrator." : "Για περισσότερες πληροφορίες παρακαλούμε, επικοινωνήστε με το φιλικό διαχειριστή του συστήματός σας.",
    "Sorry, this link doesn't seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος φαίνεται ότι δεν ισχύει πια.",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link has expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more information, please ask the person who has sent you this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "Add to your Nextcloud" : "Προσθήκη στο Nextcloud",
    "Picture view" : "Προβολή εικονιδίων"
},
"nplurals=2; plural=(n != 1);");
